# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'AccountEncryptionArgs',
    'AccountEncryptionManagedIdentityArgs',
    'AccountIdentityArgs',
    'AccountKeyDeliveryAccessControlArgs',
    'AccountStorageAccountArgs',
    'AccountStorageAccountManagedIdentityArgs',
]

@pulumi.input_type
class AccountEncryptionArgs:
    def __init__(__self__, *,
                 current_key_identifier: Optional[pulumi.Input[str]] = None,
                 key_vault_key_identifier: Optional[pulumi.Input[str]] = None,
                 managed_identity: Optional[pulumi.Input['AccountEncryptionManagedIdentityArgs']] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] current_key_identifier: The current key used to encrypt the Media Services Account, including the key version.
        :param pulumi.Input[str] key_vault_key_identifier: Specifies the URI of the Key Vault Key used to encrypt data. The key may either be versioned (for example https://vault/keys/mykey/version1) or reference a key without a version (for example https://vault/keys/mykey).
        :param pulumi.Input['AccountEncryptionManagedIdentityArgs'] managed_identity: A `managed_identity` block as defined below.
        :param pulumi.Input[str] type: Specifies the type of key used to encrypt the account data. Possible values are `SystemKey` and `CustomerKey`. Defaults to `SystemKey`.
        """
        if current_key_identifier is not None:
            pulumi.set(__self__, "current_key_identifier", current_key_identifier)
        if key_vault_key_identifier is not None:
            pulumi.set(__self__, "key_vault_key_identifier", key_vault_key_identifier)
        if managed_identity is not None:
            pulumi.set(__self__, "managed_identity", managed_identity)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="currentKeyIdentifier")
    def current_key_identifier(self) -> Optional[pulumi.Input[str]]:
        """
        The current key used to encrypt the Media Services Account, including the key version.
        """
        return pulumi.get(self, "current_key_identifier")

    @current_key_identifier.setter
    def current_key_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "current_key_identifier", value)

    @property
    @pulumi.getter(name="keyVaultKeyIdentifier")
    def key_vault_key_identifier(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the URI of the Key Vault Key used to encrypt data. The key may either be versioned (for example https://vault/keys/mykey/version1) or reference a key without a version (for example https://vault/keys/mykey).
        """
        return pulumi.get(self, "key_vault_key_identifier")

    @key_vault_key_identifier.setter
    def key_vault_key_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_vault_key_identifier", value)

    @property
    @pulumi.getter(name="managedIdentity")
    def managed_identity(self) -> Optional[pulumi.Input['AccountEncryptionManagedIdentityArgs']]:
        """
        A `managed_identity` block as defined below.
        """
        return pulumi.get(self, "managed_identity")

    @managed_identity.setter
    def managed_identity(self, value: Optional[pulumi.Input['AccountEncryptionManagedIdentityArgs']]):
        pulumi.set(self, "managed_identity", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the type of key used to encrypt the account data. Possible values are `SystemKey` and `CustomerKey`. Defaults to `SystemKey`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class AccountEncryptionManagedIdentityArgs:
    def __init__(__self__, *,
                 use_system_assigned_identity: Optional[pulumi.Input[bool]] = None,
                 user_assigned_identity_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] use_system_assigned_identity: Whether to use System Assigned Identity. Possible Values are `true` and `false`.
        :param pulumi.Input[str] user_assigned_identity_id: The ID of the User Assigned Identity. This value can only be set when `use_system_assigned_identity` is `false`
        """
        if use_system_assigned_identity is not None:
            pulumi.set(__self__, "use_system_assigned_identity", use_system_assigned_identity)
        if user_assigned_identity_id is not None:
            pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @property
    @pulumi.getter(name="useSystemAssignedIdentity")
    def use_system_assigned_identity(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use System Assigned Identity. Possible Values are `true` and `false`.
        """
        return pulumi.get(self, "use_system_assigned_identity")

    @use_system_assigned_identity.setter
    def use_system_assigned_identity(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_system_assigned_identity", value)

    @property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the User Assigned Identity. This value can only be set when `use_system_assigned_identity` is `false`
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_assigned_identity_id", value)


@pulumi.input_type
class AccountIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the type of Managed Service Identity that should be configured on this Media Services Account. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Media Services Account.
        :param pulumi.Input[str] principal_id: The Principal ID associated with this Managed Service Identity.
        :param pulumi.Input[str] tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the type of Managed Service Identity that should be configured on this Media Services Account. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Media Services Account.
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identity_ids", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class AccountKeyDeliveryAccessControlArgs:
    def __init__(__self__, *,
                 default_action: Optional[pulumi.Input[str]] = None,
                 ip_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] default_action: The Default Action to use when no rules match from `ip_allow_list`. Possible values are `Allow` and `Deny`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] ip_allow_lists: One or more IP Addresses, or CIDR Blocks which should be able to access the Key Delivery.
        """
        if default_action is not None:
            pulumi.set(__self__, "default_action", default_action)
        if ip_allow_lists is not None:
            pulumi.set(__self__, "ip_allow_lists", ip_allow_lists)

    @property
    @pulumi.getter(name="defaultAction")
    def default_action(self) -> Optional[pulumi.Input[str]]:
        """
        The Default Action to use when no rules match from `ip_allow_list`. Possible values are `Allow` and `Deny`.
        """
        return pulumi.get(self, "default_action")

    @default_action.setter
    def default_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_action", value)

    @property
    @pulumi.getter(name="ipAllowLists")
    def ip_allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        One or more IP Addresses, or CIDR Blocks which should be able to access the Key Delivery.
        """
        return pulumi.get(self, "ip_allow_lists")

    @ip_allow_lists.setter
    def ip_allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "ip_allow_lists", value)


@pulumi.input_type
class AccountStorageAccountArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 is_primary: Optional[pulumi.Input[bool]] = None,
                 managed_identity: Optional[pulumi.Input['AccountStorageAccountManagedIdentityArgs']] = None):
        """
        :param pulumi.Input[str] id: Specifies the ID of the Storage Account that will be associated with the Media Services instance.
        :param pulumi.Input[bool] is_primary: Specifies whether the storage account should be the primary account or not. Defaults to `false`.
               
               > **NOTE:** Whilst multiple `storage_account` blocks can be specified - one of them must be set to the primary
        :param pulumi.Input['AccountStorageAccountManagedIdentityArgs'] managed_identity: A `managed_identity` block as defined below.
        """
        pulumi.set(__self__, "id", id)
        if is_primary is not None:
            pulumi.set(__self__, "is_primary", is_primary)
        if managed_identity is not None:
            pulumi.set(__self__, "managed_identity", managed_identity)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the Storage Account that will be associated with the Media Services instance.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="isPrimary")
    def is_primary(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the storage account should be the primary account or not. Defaults to `false`.

        > **NOTE:** Whilst multiple `storage_account` blocks can be specified - one of them must be set to the primary
        """
        return pulumi.get(self, "is_primary")

    @is_primary.setter
    def is_primary(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_primary", value)

    @property
    @pulumi.getter(name="managedIdentity")
    def managed_identity(self) -> Optional[pulumi.Input['AccountStorageAccountManagedIdentityArgs']]:
        """
        A `managed_identity` block as defined below.
        """
        return pulumi.get(self, "managed_identity")

    @managed_identity.setter
    def managed_identity(self, value: Optional[pulumi.Input['AccountStorageAccountManagedIdentityArgs']]):
        pulumi.set(self, "managed_identity", value)


@pulumi.input_type
class AccountStorageAccountManagedIdentityArgs:
    def __init__(__self__, *,
                 use_system_assigned_identity: Optional[pulumi.Input[bool]] = None,
                 user_assigned_identity_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] use_system_assigned_identity: Whether to use System Assigned Identity. Possible Values are `true` and `false`.
        :param pulumi.Input[str] user_assigned_identity_id: The ID of the User Assigned Identity. This value can only be set when `use_system_assigned_identity` is `false`
        """
        if use_system_assigned_identity is not None:
            pulumi.set(__self__, "use_system_assigned_identity", use_system_assigned_identity)
        if user_assigned_identity_id is not None:
            pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @property
    @pulumi.getter(name="useSystemAssignedIdentity")
    def use_system_assigned_identity(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use System Assigned Identity. Possible Values are `true` and `false`.
        """
        return pulumi.get(self, "use_system_assigned_identity")

    @use_system_assigned_identity.setter
    def use_system_assigned_identity(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_system_assigned_identity", value)

    @property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the User Assigned Identity. This value can only be set when `use_system_assigned_identity` is `false`
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_assigned_identity_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSubscriptionTemplateDeploymentResult',
    'AwaitableGetSubscriptionTemplateDeploymentResult',
    'get_subscription_template_deployment',
    'get_subscription_template_deployment_output',
]

@pulumi.output_type
class GetSubscriptionTemplateDeploymentResult:
    """
    A collection of values returned by getSubscriptionTemplateDeployment.
    """
    def __init__(__self__, id=None, name=None, output_content=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if output_content and not isinstance(output_content, str):
            raise TypeError("Expected argument 'output_content' to be a str")
        pulumi.set(__self__, "output_content", output_content)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="outputContent")
    def output_content(self) -> str:
        """
        The JSON Content of the Outputs of the ARM Template Deployment.
        """
        return pulumi.get(self, "output_content")


class AwaitableGetSubscriptionTemplateDeploymentResult(GetSubscriptionTemplateDeploymentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSubscriptionTemplateDeploymentResult(
            id=self.id,
            name=self.name,
            output_content=self.output_content)


def get_subscription_template_deployment(name: Optional[str] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSubscriptionTemplateDeploymentResult:
    """
    Use this data source to access information about an existing Subscription Template Deployment.


    :param str name: The name of this Subscription Template Deployment.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:core/getSubscriptionTemplateDeployment:getSubscriptionTemplateDeployment', __args__, opts=opts, typ=GetSubscriptionTemplateDeploymentResult).value

    return AwaitableGetSubscriptionTemplateDeploymentResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        output_content=pulumi.get(__ret__, 'output_content'))


@_utilities.lift_output_func(get_subscription_template_deployment)
def get_subscription_template_deployment_output(name: Optional[pulumi.Input[str]] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSubscriptionTemplateDeploymentResult]:
    """
    Use this data source to access information about an existing Subscription Template Deployment.


    :param str name: The name of this Subscription Template Deployment.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LogzSubAccountTagRuleArgs', 'LogzSubAccountTagRule']

@pulumi.input_type
class LogzSubAccountTagRuleArgs:
    def __init__(__self__, *,
                 logz_sub_account_id: pulumi.Input[str],
                 send_aad_logs: Optional[pulumi.Input[bool]] = None,
                 send_activity_logs: Optional[pulumi.Input[bool]] = None,
                 send_subscription_logs: Optional[pulumi.Input[bool]] = None,
                 tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]]] = None):
        """
        The set of arguments for constructing a LogzSubAccountTagRule resource.
        :param pulumi.Input[str] logz_sub_account_id: The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        :param pulumi.Input[bool] send_aad_logs: Whether AAD logs should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_activity_logs: Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_subscription_logs: Whether subscription logs should be sent to the Monitor resource?
        :param pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]] tag_filters: One or more (up to 10) `tag_filter` blocks as defined below.
        """
        pulumi.set(__self__, "logz_sub_account_id", logz_sub_account_id)
        if send_aad_logs is not None:
            pulumi.set(__self__, "send_aad_logs", send_aad_logs)
        if send_activity_logs is not None:
            pulumi.set(__self__, "send_activity_logs", send_activity_logs)
        if send_subscription_logs is not None:
            pulumi.set(__self__, "send_subscription_logs", send_subscription_logs)
        if tag_filters is not None:
            pulumi.set(__self__, "tag_filters", tag_filters)

    @property
    @pulumi.getter(name="logzSubAccountId")
    def logz_sub_account_id(self) -> pulumi.Input[str]:
        """
        The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        """
        return pulumi.get(self, "logz_sub_account_id")

    @logz_sub_account_id.setter
    def logz_sub_account_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "logz_sub_account_id", value)

    @property
    @pulumi.getter(name="sendAadLogs")
    def send_aad_logs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether AAD logs should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_aad_logs")

    @send_aad_logs.setter
    def send_aad_logs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_aad_logs", value)

    @property
    @pulumi.getter(name="sendActivityLogs")
    def send_activity_logs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_activity_logs")

    @send_activity_logs.setter
    def send_activity_logs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_activity_logs", value)

    @property
    @pulumi.getter(name="sendSubscriptionLogs")
    def send_subscription_logs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether subscription logs should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_subscription_logs")

    @send_subscription_logs.setter
    def send_subscription_logs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_subscription_logs", value)

    @property
    @pulumi.getter(name="tagFilters")
    def tag_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]]]:
        """
        One or more (up to 10) `tag_filter` blocks as defined below.
        """
        return pulumi.get(self, "tag_filters")

    @tag_filters.setter
    def tag_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]]]):
        pulumi.set(self, "tag_filters", value)


@pulumi.input_type
class _LogzSubAccountTagRuleState:
    def __init__(__self__, *,
                 logz_sub_account_id: Optional[pulumi.Input[str]] = None,
                 send_aad_logs: Optional[pulumi.Input[bool]] = None,
                 send_activity_logs: Optional[pulumi.Input[bool]] = None,
                 send_subscription_logs: Optional[pulumi.Input[bool]] = None,
                 tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]]] = None):
        """
        Input properties used for looking up and filtering LogzSubAccountTagRule resources.
        :param pulumi.Input[str] logz_sub_account_id: The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        :param pulumi.Input[bool] send_aad_logs: Whether AAD logs should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_activity_logs: Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_subscription_logs: Whether subscription logs should be sent to the Monitor resource?
        :param pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]] tag_filters: One or more (up to 10) `tag_filter` blocks as defined below.
        """
        if logz_sub_account_id is not None:
            pulumi.set(__self__, "logz_sub_account_id", logz_sub_account_id)
        if send_aad_logs is not None:
            pulumi.set(__self__, "send_aad_logs", send_aad_logs)
        if send_activity_logs is not None:
            pulumi.set(__self__, "send_activity_logs", send_activity_logs)
        if send_subscription_logs is not None:
            pulumi.set(__self__, "send_subscription_logs", send_subscription_logs)
        if tag_filters is not None:
            pulumi.set(__self__, "tag_filters", tag_filters)

    @property
    @pulumi.getter(name="logzSubAccountId")
    def logz_sub_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        """
        return pulumi.get(self, "logz_sub_account_id")

    @logz_sub_account_id.setter
    def logz_sub_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logz_sub_account_id", value)

    @property
    @pulumi.getter(name="sendAadLogs")
    def send_aad_logs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether AAD logs should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_aad_logs")

    @send_aad_logs.setter
    def send_aad_logs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_aad_logs", value)

    @property
    @pulumi.getter(name="sendActivityLogs")
    def send_activity_logs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_activity_logs")

    @send_activity_logs.setter
    def send_activity_logs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_activity_logs", value)

    @property
    @pulumi.getter(name="sendSubscriptionLogs")
    def send_subscription_logs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether subscription logs should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_subscription_logs")

    @send_subscription_logs.setter
    def send_subscription_logs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_subscription_logs", value)

    @property
    @pulumi.getter(name="tagFilters")
    def tag_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]]]:
        """
        One or more (up to 10) `tag_filter` blocks as defined below.
        """
        return pulumi.get(self, "tag_filters")

    @tag_filters.setter
    def tag_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LogzSubAccountTagRuleTagFilterArgs']]]]):
        pulumi.set(self, "tag_filters", value)


class LogzSubAccountTagRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 logz_sub_account_id: Optional[pulumi.Input[str]] = None,
                 send_aad_logs: Optional[pulumi.Input[bool]] = None,
                 send_activity_logs: Optional[pulumi.Input[bool]] = None,
                 send_subscription_logs: Optional[pulumi.Input[bool]] = None,
                 tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogzSubAccountTagRuleTagFilterArgs']]]]] = None,
                 __props__=None):
        """
        Manages a Logz Sub Account Tag Rule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_logz_monitor = azure.monitoring.LogzMonitor("exampleLogzMonitor",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            plan=azure.monitoring.LogzMonitorPlanArgs(
                billing_cycle="MONTHLY",
                effective_date="2022-06-06T00:00:00Z",
                usage_type="COMMITTED",
            ),
            user=azure.monitoring.LogzMonitorUserArgs(
                email="user@example.com",
                first_name="Example",
                last_name="User",
                phone_number="+12313803556",
            ))
        example_logz_sub_account = azure.monitoring.LogzSubAccount("exampleLogzSubAccount",
            logz_monitor_id=example_logz_monitor.id,
            user=azure.monitoring.LogzSubAccountUserArgs(
                email=example_logz_monitor.user.email,
                first_name=example_logz_monitor.user.first_name,
                last_name=example_logz_monitor.user.last_name,
                phone_number=example_logz_monitor.user.phone_number,
            ))
        example_logz_sub_account_tag_rule = azure.monitoring.LogzSubAccountTagRule("exampleLogzSubAccountTagRule",
            logz_sub_account_id=example_logz_sub_account.id,
            send_aad_logs=True,
            send_activity_logs=True,
            send_subscription_logs=True,
            tag_filters=[
                azure.monitoring.LogzSubAccountTagRuleTagFilterArgs(
                    name="name1",
                    action="Include",
                    value="value1",
                ),
                azure.monitoring.LogzSubAccountTagRuleTagFilterArgs(
                    name="name2",
                    action="Exclude",
                    value="value2",
                ),
            ])
        ```

        ## Import

        Logz Sub Account Tag Rules can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:monitoring/logzSubAccountTagRule:LogzSubAccountTagRule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Logz/monitors/monitor1/accounts/subAccount1/tagRules/ruleSet1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] logz_sub_account_id: The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        :param pulumi.Input[bool] send_aad_logs: Whether AAD logs should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_activity_logs: Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_subscription_logs: Whether subscription logs should be sent to the Monitor resource?
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogzSubAccountTagRuleTagFilterArgs']]]] tag_filters: One or more (up to 10) `tag_filter` blocks as defined below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogzSubAccountTagRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Logz Sub Account Tag Rule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_logz_monitor = azure.monitoring.LogzMonitor("exampleLogzMonitor",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            plan=azure.monitoring.LogzMonitorPlanArgs(
                billing_cycle="MONTHLY",
                effective_date="2022-06-06T00:00:00Z",
                usage_type="COMMITTED",
            ),
            user=azure.monitoring.LogzMonitorUserArgs(
                email="user@example.com",
                first_name="Example",
                last_name="User",
                phone_number="+12313803556",
            ))
        example_logz_sub_account = azure.monitoring.LogzSubAccount("exampleLogzSubAccount",
            logz_monitor_id=example_logz_monitor.id,
            user=azure.monitoring.LogzSubAccountUserArgs(
                email=example_logz_monitor.user.email,
                first_name=example_logz_monitor.user.first_name,
                last_name=example_logz_monitor.user.last_name,
                phone_number=example_logz_monitor.user.phone_number,
            ))
        example_logz_sub_account_tag_rule = azure.monitoring.LogzSubAccountTagRule("exampleLogzSubAccountTagRule",
            logz_sub_account_id=example_logz_sub_account.id,
            send_aad_logs=True,
            send_activity_logs=True,
            send_subscription_logs=True,
            tag_filters=[
                azure.monitoring.LogzSubAccountTagRuleTagFilterArgs(
                    name="name1",
                    action="Include",
                    value="value1",
                ),
                azure.monitoring.LogzSubAccountTagRuleTagFilterArgs(
                    name="name2",
                    action="Exclude",
                    value="value2",
                ),
            ])
        ```

        ## Import

        Logz Sub Account Tag Rules can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:monitoring/logzSubAccountTagRule:LogzSubAccountTagRule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Logz/monitors/monitor1/accounts/subAccount1/tagRules/ruleSet1
        ```

        :param str resource_name: The name of the resource.
        :param LogzSubAccountTagRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogzSubAccountTagRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 logz_sub_account_id: Optional[pulumi.Input[str]] = None,
                 send_aad_logs: Optional[pulumi.Input[bool]] = None,
                 send_activity_logs: Optional[pulumi.Input[bool]] = None,
                 send_subscription_logs: Optional[pulumi.Input[bool]] = None,
                 tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogzSubAccountTagRuleTagFilterArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogzSubAccountTagRuleArgs.__new__(LogzSubAccountTagRuleArgs)

            if logz_sub_account_id is None and not opts.urn:
                raise TypeError("Missing required property 'logz_sub_account_id'")
            __props__.__dict__["logz_sub_account_id"] = logz_sub_account_id
            __props__.__dict__["send_aad_logs"] = send_aad_logs
            __props__.__dict__["send_activity_logs"] = send_activity_logs
            __props__.__dict__["send_subscription_logs"] = send_subscription_logs
            __props__.__dict__["tag_filters"] = tag_filters
        super(LogzSubAccountTagRule, __self__).__init__(
            'azure:monitoring/logzSubAccountTagRule:LogzSubAccountTagRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            logz_sub_account_id: Optional[pulumi.Input[str]] = None,
            send_aad_logs: Optional[pulumi.Input[bool]] = None,
            send_activity_logs: Optional[pulumi.Input[bool]] = None,
            send_subscription_logs: Optional[pulumi.Input[bool]] = None,
            tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogzSubAccountTagRuleTagFilterArgs']]]]] = None) -> 'LogzSubAccountTagRule':
        """
        Get an existing LogzSubAccountTagRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] logz_sub_account_id: The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        :param pulumi.Input[bool] send_aad_logs: Whether AAD logs should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_activity_logs: Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        :param pulumi.Input[bool] send_subscription_logs: Whether subscription logs should be sent to the Monitor resource?
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogzSubAccountTagRuleTagFilterArgs']]]] tag_filters: One or more (up to 10) `tag_filter` blocks as defined below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogzSubAccountTagRuleState.__new__(_LogzSubAccountTagRuleState)

        __props__.__dict__["logz_sub_account_id"] = logz_sub_account_id
        __props__.__dict__["send_aad_logs"] = send_aad_logs
        __props__.__dict__["send_activity_logs"] = send_activity_logs
        __props__.__dict__["send_subscription_logs"] = send_subscription_logs
        __props__.__dict__["tag_filters"] = tag_filters
        return LogzSubAccountTagRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="logzSubAccountId")
    def logz_sub_account_id(self) -> pulumi.Output[str]:
        """
        The ID of the Logz Sub Account. Changing this forces a new Logz Sub Account Tag Rule to be created.
        """
        return pulumi.get(self, "logz_sub_account_id")

    @property
    @pulumi.getter(name="sendAadLogs")
    def send_aad_logs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether AAD logs should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_aad_logs")

    @property
    @pulumi.getter(name="sendActivityLogs")
    def send_activity_logs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether activity logs from this Logz Sub Account Tag Rule should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_activity_logs")

    @property
    @pulumi.getter(name="sendSubscriptionLogs")
    def send_subscription_logs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether subscription logs should be sent to the Monitor resource?
        """
        return pulumi.get(self, "send_subscription_logs")

    @property
    @pulumi.getter(name="tagFilters")
    def tag_filters(self) -> pulumi.Output[Optional[Sequence['outputs.LogzSubAccountTagRuleTagFilter']]]:
        """
        One or more (up to 10) `tag_filter` blocks as defined below.
        """
        return pulumi.get(self, "tag_filters")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GrafanaAzureMonitorWorkspaceIntegrationArgs',
    'GrafanaIdentityArgs',
    'GetGrafanaIdentityArgs',
]

@pulumi.input_type
class GrafanaAzureMonitorWorkspaceIntegrationArgs:
    def __init__(__self__, *,
                 resource_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] resource_id: Specifies the resource ID of the connected Azure Monitor Workspace.
        """
        pulumi.set(__self__, "resource_id", resource_id)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[str]:
        """
        Specifies the resource ID of the connected Azure Monitor Workspace.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_id", value)


@pulumi.input_type
class GrafanaIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the type of Managed Service Identity. Possible values are `SystemAssigned`, `UserAssigned`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identity_ids: Specifies the list of User Assigned Managed Service Identity IDs which should be assigned to this Dashboard Grafana. Changing this forces a new resource to be created.
        :param pulumi.Input[str] principal_id: The Principal ID associated with this Managed Service Identity.
        :param pulumi.Input[str] tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the type of Managed Service Identity. Possible values are `SystemAssigned`, `UserAssigned`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the list of User Assigned Managed Service Identity IDs which should be assigned to this Dashboard Grafana. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identity_ids", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class GetGrafanaIdentityArgs:
    def __init__(__self__, *,
                 principal_id: str,
                 tenant_id: str,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: str):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: str):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: str):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[Sequence[str]]):
        pulumi.set(self, "identity_ids", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServicePlanArgs', 'ServicePlan']

@pulumi.input_type
class ServicePlanArgs:
    def __init__(__self__, *,
                 allowed_regions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 resource_group_name: pulumi.Input[str],
                 default_auto_shutdown: Optional[pulumi.Input['ServicePlanDefaultAutoShutdownArgs']] = None,
                 default_connection: Optional[pulumi.Input['ServicePlanDefaultConnectionArgs']] = None,
                 default_network_subnet_id: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 shared_gallery_id: Optional[pulumi.Input[str]] = None,
                 support: Optional[pulumi.Input['ServicePlanSupportArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ServicePlan resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_regions: The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input['ServicePlanDefaultAutoShutdownArgs'] default_auto_shutdown: A `default_auto_shutdown` block as defined below.
        :param pulumi.Input['ServicePlanDefaultConnectionArgs'] default_connection: A `default_connection` block as defined below.
        :param pulumi.Input[str] default_network_subnet_id: The resource ID of the Subnet for the Lab Service Plan network profile.
        :param pulumi.Input[str] location: The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Lab Service Plan. Changing this forces a new resource to be created.
        :param pulumi.Input[str] shared_gallery_id: The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.
               
               > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        :param pulumi.Input['ServicePlanSupportArgs'] support: A `support` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Lab Service Plan.
        """
        pulumi.set(__self__, "allowed_regions", allowed_regions)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if default_auto_shutdown is not None:
            pulumi.set(__self__, "default_auto_shutdown", default_auto_shutdown)
        if default_connection is not None:
            pulumi.set(__self__, "default_connection", default_connection)
        if default_network_subnet_id is not None:
            pulumi.set(__self__, "default_network_subnet_id", default_network_subnet_id)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if shared_gallery_id is not None:
            pulumi.set(__self__, "shared_gallery_id", shared_gallery_id)
        if support is not None:
            pulumi.set(__self__, "support", support)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="allowedRegions")
    def allowed_regions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        """
        return pulumi.get(self, "allowed_regions")

    @allowed_regions.setter
    def allowed_regions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "allowed_regions", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="defaultAutoShutdown")
    def default_auto_shutdown(self) -> Optional[pulumi.Input['ServicePlanDefaultAutoShutdownArgs']]:
        """
        A `default_auto_shutdown` block as defined below.
        """
        return pulumi.get(self, "default_auto_shutdown")

    @default_auto_shutdown.setter
    def default_auto_shutdown(self, value: Optional[pulumi.Input['ServicePlanDefaultAutoShutdownArgs']]):
        pulumi.set(self, "default_auto_shutdown", value)

    @property
    @pulumi.getter(name="defaultConnection")
    def default_connection(self) -> Optional[pulumi.Input['ServicePlanDefaultConnectionArgs']]:
        """
        A `default_connection` block as defined below.
        """
        return pulumi.get(self, "default_connection")

    @default_connection.setter
    def default_connection(self, value: Optional[pulumi.Input['ServicePlanDefaultConnectionArgs']]):
        pulumi.set(self, "default_connection", value)

    @property
    @pulumi.getter(name="defaultNetworkSubnetId")
    def default_network_subnet_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the Subnet for the Lab Service Plan network profile.
        """
        return pulumi.get(self, "default_network_subnet_id")

    @default_network_subnet_id.setter
    def default_network_subnet_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_network_subnet_id", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Lab Service Plan. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sharedGalleryId")
    def shared_gallery_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.

        > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        """
        return pulumi.get(self, "shared_gallery_id")

    @shared_gallery_id.setter
    def shared_gallery_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shared_gallery_id", value)

    @property
    @pulumi.getter
    def support(self) -> Optional[pulumi.Input['ServicePlanSupportArgs']]:
        """
        A `support` block as defined below.
        """
        return pulumi.get(self, "support")

    @support.setter
    def support(self, value: Optional[pulumi.Input['ServicePlanSupportArgs']]):
        pulumi.set(self, "support", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Lab Service Plan.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ServicePlanState:
    def __init__(__self__, *,
                 allowed_regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 default_auto_shutdown: Optional[pulumi.Input['ServicePlanDefaultAutoShutdownArgs']] = None,
                 default_connection: Optional[pulumi.Input['ServicePlanDefaultConnectionArgs']] = None,
                 default_network_subnet_id: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 shared_gallery_id: Optional[pulumi.Input[str]] = None,
                 support: Optional[pulumi.Input['ServicePlanSupportArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ServicePlan resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_regions: The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        :param pulumi.Input['ServicePlanDefaultAutoShutdownArgs'] default_auto_shutdown: A `default_auto_shutdown` block as defined below.
        :param pulumi.Input['ServicePlanDefaultConnectionArgs'] default_connection: A `default_connection` block as defined below.
        :param pulumi.Input[str] default_network_subnet_id: The resource ID of the Subnet for the Lab Service Plan network profile.
        :param pulumi.Input[str] location: The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Lab Service Plan. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] shared_gallery_id: The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.
               
               > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        :param pulumi.Input['ServicePlanSupportArgs'] support: A `support` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Lab Service Plan.
        """
        if allowed_regions is not None:
            pulumi.set(__self__, "allowed_regions", allowed_regions)
        if default_auto_shutdown is not None:
            pulumi.set(__self__, "default_auto_shutdown", default_auto_shutdown)
        if default_connection is not None:
            pulumi.set(__self__, "default_connection", default_connection)
        if default_network_subnet_id is not None:
            pulumi.set(__self__, "default_network_subnet_id", default_network_subnet_id)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if shared_gallery_id is not None:
            pulumi.set(__self__, "shared_gallery_id", shared_gallery_id)
        if support is not None:
            pulumi.set(__self__, "support", support)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="allowedRegions")
    def allowed_regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        """
        return pulumi.get(self, "allowed_regions")

    @allowed_regions.setter
    def allowed_regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_regions", value)

    @property
    @pulumi.getter(name="defaultAutoShutdown")
    def default_auto_shutdown(self) -> Optional[pulumi.Input['ServicePlanDefaultAutoShutdownArgs']]:
        """
        A `default_auto_shutdown` block as defined below.
        """
        return pulumi.get(self, "default_auto_shutdown")

    @default_auto_shutdown.setter
    def default_auto_shutdown(self, value: Optional[pulumi.Input['ServicePlanDefaultAutoShutdownArgs']]):
        pulumi.set(self, "default_auto_shutdown", value)

    @property
    @pulumi.getter(name="defaultConnection")
    def default_connection(self) -> Optional[pulumi.Input['ServicePlanDefaultConnectionArgs']]:
        """
        A `default_connection` block as defined below.
        """
        return pulumi.get(self, "default_connection")

    @default_connection.setter
    def default_connection(self, value: Optional[pulumi.Input['ServicePlanDefaultConnectionArgs']]):
        pulumi.set(self, "default_connection", value)

    @property
    @pulumi.getter(name="defaultNetworkSubnetId")
    def default_network_subnet_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the Subnet for the Lab Service Plan network profile.
        """
        return pulumi.get(self, "default_network_subnet_id")

    @default_network_subnet_id.setter
    def default_network_subnet_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_network_subnet_id", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Lab Service Plan. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="sharedGalleryId")
    def shared_gallery_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.

        > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        """
        return pulumi.get(self, "shared_gallery_id")

    @shared_gallery_id.setter
    def shared_gallery_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shared_gallery_id", value)

    @property
    @pulumi.getter
    def support(self) -> Optional[pulumi.Input['ServicePlanSupportArgs']]:
        """
        A `support` block as defined below.
        """
        return pulumi.get(self, "support")

    @support.setter
    def support(self, value: Optional[pulumi.Input['ServicePlanSupportArgs']]):
        pulumi.set(self, "support", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Lab Service Plan.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class ServicePlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 default_auto_shutdown: Optional[pulumi.Input[pulumi.InputType['ServicePlanDefaultAutoShutdownArgs']]] = None,
                 default_connection: Optional[pulumi.Input[pulumi.InputType['ServicePlanDefaultConnectionArgs']]] = None,
                 default_network_subnet_id: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 shared_gallery_id: Optional[pulumi.Input[str]] = None,
                 support: Optional[pulumi.Input[pulumi.InputType['ServicePlanSupportArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Manages a Lab Service Plan.

        > **Note:** Before using this resource, it's required to submit the request of registering the provider with Azure CLI `az provider register --namespace Microsoft.LabServices`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_service_plan = azure.lab.ServicePlan("exampleServicePlan",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            allowed_regions=[example_resource_group.location])
        ```

        ## Import

        Lab Service Plans can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:lab/servicePlan:ServicePlan example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.LabServices/labPlans/labPlan1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_regions: The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        :param pulumi.Input[pulumi.InputType['ServicePlanDefaultAutoShutdownArgs']] default_auto_shutdown: A `default_auto_shutdown` block as defined below.
        :param pulumi.Input[pulumi.InputType['ServicePlanDefaultConnectionArgs']] default_connection: A `default_connection` block as defined below.
        :param pulumi.Input[str] default_network_subnet_id: The resource ID of the Subnet for the Lab Service Plan network profile.
        :param pulumi.Input[str] location: The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Lab Service Plan. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] shared_gallery_id: The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.
               
               > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        :param pulumi.Input[pulumi.InputType['ServicePlanSupportArgs']] support: A `support` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Lab Service Plan.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServicePlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Lab Service Plan.

        > **Note:** Before using this resource, it's required to submit the request of registering the provider with Azure CLI `az provider register --namespace Microsoft.LabServices`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_service_plan = azure.lab.ServicePlan("exampleServicePlan",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            allowed_regions=[example_resource_group.location])
        ```

        ## Import

        Lab Service Plans can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:lab/servicePlan:ServicePlan example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.LabServices/labPlans/labPlan1
        ```

        :param str resource_name: The name of the resource.
        :param ServicePlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServicePlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 default_auto_shutdown: Optional[pulumi.Input[pulumi.InputType['ServicePlanDefaultAutoShutdownArgs']]] = None,
                 default_connection: Optional[pulumi.Input[pulumi.InputType['ServicePlanDefaultConnectionArgs']]] = None,
                 default_network_subnet_id: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 shared_gallery_id: Optional[pulumi.Input[str]] = None,
                 support: Optional[pulumi.Input[pulumi.InputType['ServicePlanSupportArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServicePlanArgs.__new__(ServicePlanArgs)

            if allowed_regions is None and not opts.urn:
                raise TypeError("Missing required property 'allowed_regions'")
            __props__.__dict__["allowed_regions"] = allowed_regions
            __props__.__dict__["default_auto_shutdown"] = default_auto_shutdown
            __props__.__dict__["default_connection"] = default_connection
            __props__.__dict__["default_network_subnet_id"] = default_network_subnet_id
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["shared_gallery_id"] = shared_gallery_id
            __props__.__dict__["support"] = support
            __props__.__dict__["tags"] = tags
        super(ServicePlan, __self__).__init__(
            'azure:lab/servicePlan:ServicePlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            default_auto_shutdown: Optional[pulumi.Input[pulumi.InputType['ServicePlanDefaultAutoShutdownArgs']]] = None,
            default_connection: Optional[pulumi.Input[pulumi.InputType['ServicePlanDefaultConnectionArgs']]] = None,
            default_network_subnet_id: Optional[pulumi.Input[str]] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            shared_gallery_id: Optional[pulumi.Input[str]] = None,
            support: Optional[pulumi.Input[pulumi.InputType['ServicePlanSupportArgs']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'ServicePlan':
        """
        Get an existing ServicePlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_regions: The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        :param pulumi.Input[pulumi.InputType['ServicePlanDefaultAutoShutdownArgs']] default_auto_shutdown: A `default_auto_shutdown` block as defined below.
        :param pulumi.Input[pulumi.InputType['ServicePlanDefaultConnectionArgs']] default_connection: A `default_connection` block as defined below.
        :param pulumi.Input[str] default_network_subnet_id: The resource ID of the Subnet for the Lab Service Plan network profile.
        :param pulumi.Input[str] location: The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Lab Service Plan. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] shared_gallery_id: The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.
               
               > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        :param pulumi.Input[pulumi.InputType['ServicePlanSupportArgs']] support: A `support` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Lab Service Plan.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServicePlanState.__new__(_ServicePlanState)

        __props__.__dict__["allowed_regions"] = allowed_regions
        __props__.__dict__["default_auto_shutdown"] = default_auto_shutdown
        __props__.__dict__["default_connection"] = default_connection
        __props__.__dict__["default_network_subnet_id"] = default_network_subnet_id
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["shared_gallery_id"] = shared_gallery_id
        __props__.__dict__["support"] = support
        __props__.__dict__["tags"] = tags
        return ServicePlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedRegions")
    def allowed_regions(self) -> pulumi.Output[Sequence[str]]:
        """
        The allowed regions for the lab creator to use when creating labs using this Lab Service Plan. The allowed region's count must be between `1` and `28`.
        """
        return pulumi.get(self, "allowed_regions")

    @property
    @pulumi.getter(name="defaultAutoShutdown")
    def default_auto_shutdown(self) -> pulumi.Output[Optional['outputs.ServicePlanDefaultAutoShutdown']]:
        """
        A `default_auto_shutdown` block as defined below.
        """
        return pulumi.get(self, "default_auto_shutdown")

    @property
    @pulumi.getter(name="defaultConnection")
    def default_connection(self) -> pulumi.Output[Optional['outputs.ServicePlanDefaultConnection']]:
        """
        A `default_connection` block as defined below.
        """
        return pulumi.get(self, "default_connection")

    @property
    @pulumi.getter(name="defaultNetworkSubnetId")
    def default_network_subnet_id(self) -> pulumi.Output[Optional[str]]:
        """
        The resource ID of the Subnet for the Lab Service Plan network profile.
        """
        return pulumi.get(self, "default_network_subnet_id")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The Azure Region where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Lab Service Plan. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the Resource Group where the Lab Service Plan should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="sharedGalleryId")
    def shared_gallery_id(self) -> pulumi.Output[Optional[str]]:
        """
        The resource ID of the Shared Image Gallery attached to this Lab Service Plan. When saving a lab template virtual machine image it will be persisted in this gallery. The shared images from the gallery can be made available to use when creating new labs.

        > **NOTE:** The built-in `Azure Lab Services` Service Principal with role needs to be assigned to the Shared Image Gallery while using this property.
        """
        return pulumi.get(self, "shared_gallery_id")

    @property
    @pulumi.getter
    def support(self) -> pulumi.Output[Optional['outputs.ServicePlanSupport']]:
        """
        A `support` block as defined below.
        """
        return pulumi.get(self, "support")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags which should be assigned to the Lab Service Plan.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['LiveEventOutputArgs', 'LiveEventOutput']

@pulumi.input_type
class LiveEventOutputArgs:
    def __init__(__self__, *,
                 archive_window_duration: pulumi.Input[str],
                 asset_name: pulumi.Input[str],
                 live_event_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 hls_fragments_per_ts_segment: Optional[pulumi.Input[int]] = None,
                 manifest_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 output_snap_time_in_seconds: Optional[pulumi.Input[int]] = None,
                 rewind_window_duration: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LiveEventOutput resource.
        :param pulumi.Input[str] archive_window_duration: `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] asset_name: The asset that the live output will write to. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] live_event_id: The id of the live event. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] description: The description of the live output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] hls_fragments_per_ts_segment: The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] manifest_name: The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] name: The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] output_snap_time_in_seconds: The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] rewind_window_duration: `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        pulumi.set(__self__, "archive_window_duration", archive_window_duration)
        pulumi.set(__self__, "asset_name", asset_name)
        pulumi.set(__self__, "live_event_id", live_event_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if hls_fragments_per_ts_segment is not None:
            pulumi.set(__self__, "hls_fragments_per_ts_segment", hls_fragments_per_ts_segment)
        if manifest_name is not None:
            pulumi.set(__self__, "manifest_name", manifest_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if output_snap_time_in_seconds is not None:
            pulumi.set(__self__, "output_snap_time_in_seconds", output_snap_time_in_seconds)
        if rewind_window_duration is not None:
            pulumi.set(__self__, "rewind_window_duration", rewind_window_duration)

    @property
    @pulumi.getter(name="archiveWindowDuration")
    def archive_window_duration(self) -> pulumi.Input[str]:
        """
        `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "archive_window_duration")

    @archive_window_duration.setter
    def archive_window_duration(self, value: pulumi.Input[str]):
        pulumi.set(self, "archive_window_duration", value)

    @property
    @pulumi.getter(name="assetName")
    def asset_name(self) -> pulumi.Input[str]:
        """
        The asset that the live output will write to. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "asset_name")

    @asset_name.setter
    def asset_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "asset_name", value)

    @property
    @pulumi.getter(name="liveEventId")
    def live_event_id(self) -> pulumi.Input[str]:
        """
        The id of the live event. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "live_event_id")

    @live_event_id.setter
    def live_event_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "live_event_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the live output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="hlsFragmentsPerTsSegment")
    def hls_fragments_per_ts_segment(self) -> Optional[pulumi.Input[int]]:
        """
        The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "hls_fragments_per_ts_segment")

    @hls_fragments_per_ts_segment.setter
    def hls_fragments_per_ts_segment(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "hls_fragments_per_ts_segment", value)

    @property
    @pulumi.getter(name="manifestName")
    def manifest_name(self) -> Optional[pulumi.Input[str]]:
        """
        The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "manifest_name")

    @manifest_name.setter
    def manifest_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manifest_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="outputSnapTimeInSeconds")
    def output_snap_time_in_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "output_snap_time_in_seconds")

    @output_snap_time_in_seconds.setter
    def output_snap_time_in_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "output_snap_time_in_seconds", value)

    @property
    @pulumi.getter(name="rewindWindowDuration")
    def rewind_window_duration(self) -> Optional[pulumi.Input[str]]:
        """
        `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "rewind_window_duration")

    @rewind_window_duration.setter
    def rewind_window_duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rewind_window_duration", value)


@pulumi.input_type
class _LiveEventOutputState:
    def __init__(__self__, *,
                 archive_window_duration: Optional[pulumi.Input[str]] = None,
                 asset_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hls_fragments_per_ts_segment: Optional[pulumi.Input[int]] = None,
                 live_event_id: Optional[pulumi.Input[str]] = None,
                 manifest_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 output_snap_time_in_seconds: Optional[pulumi.Input[int]] = None,
                 rewind_window_duration: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LiveEventOutput resources.
        :param pulumi.Input[str] archive_window_duration: `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] asset_name: The asset that the live output will write to. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] description: The description of the live output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] hls_fragments_per_ts_segment: The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] live_event_id: The id of the live event. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] manifest_name: The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] name: The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] output_snap_time_in_seconds: The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] rewind_window_duration: `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        if archive_window_duration is not None:
            pulumi.set(__self__, "archive_window_duration", archive_window_duration)
        if asset_name is not None:
            pulumi.set(__self__, "asset_name", asset_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if hls_fragments_per_ts_segment is not None:
            pulumi.set(__self__, "hls_fragments_per_ts_segment", hls_fragments_per_ts_segment)
        if live_event_id is not None:
            pulumi.set(__self__, "live_event_id", live_event_id)
        if manifest_name is not None:
            pulumi.set(__self__, "manifest_name", manifest_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if output_snap_time_in_seconds is not None:
            pulumi.set(__self__, "output_snap_time_in_seconds", output_snap_time_in_seconds)
        if rewind_window_duration is not None:
            pulumi.set(__self__, "rewind_window_duration", rewind_window_duration)

    @property
    @pulumi.getter(name="archiveWindowDuration")
    def archive_window_duration(self) -> Optional[pulumi.Input[str]]:
        """
        `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "archive_window_duration")

    @archive_window_duration.setter
    def archive_window_duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "archive_window_duration", value)

    @property
    @pulumi.getter(name="assetName")
    def asset_name(self) -> Optional[pulumi.Input[str]]:
        """
        The asset that the live output will write to. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "asset_name")

    @asset_name.setter
    def asset_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "asset_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the live output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="hlsFragmentsPerTsSegment")
    def hls_fragments_per_ts_segment(self) -> Optional[pulumi.Input[int]]:
        """
        The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "hls_fragments_per_ts_segment")

    @hls_fragments_per_ts_segment.setter
    def hls_fragments_per_ts_segment(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "hls_fragments_per_ts_segment", value)

    @property
    @pulumi.getter(name="liveEventId")
    def live_event_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the live event. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "live_event_id")

    @live_event_id.setter
    def live_event_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "live_event_id", value)

    @property
    @pulumi.getter(name="manifestName")
    def manifest_name(self) -> Optional[pulumi.Input[str]]:
        """
        The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "manifest_name")

    @manifest_name.setter
    def manifest_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manifest_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="outputSnapTimeInSeconds")
    def output_snap_time_in_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "output_snap_time_in_seconds")

    @output_snap_time_in_seconds.setter
    def output_snap_time_in_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "output_snap_time_in_seconds", value)

    @property
    @pulumi.getter(name="rewindWindowDuration")
    def rewind_window_duration(self) -> Optional[pulumi.Input[str]]:
        """
        `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "rewind_window_duration")

    @rewind_window_duration.setter
    def rewind_window_duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rewind_window_duration", value)


class LiveEventOutput(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 archive_window_duration: Optional[pulumi.Input[str]] = None,
                 asset_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hls_fragments_per_ts_segment: Optional[pulumi.Input[int]] = None,
                 live_event_id: Optional[pulumi.Input[str]] = None,
                 manifest_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 output_snap_time_in_seconds: Optional[pulumi.Input[int]] = None,
                 rewind_window_duration: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Azure Media Live Event Output.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_account = azure.storage.Account("exampleAccount",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            account_tier="Standard",
            account_replication_type="GRS")
        example_service_account = azure.media.ServiceAccount("exampleServiceAccount",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            storage_accounts=[azure.media.ServiceAccountStorageAccountArgs(
                id=example_account.id,
                is_primary=True,
            )])
        example_asset = azure.media.Asset("exampleAsset",
            resource_group_name=example_resource_group.name,
            media_services_account_name=example_service_account.name)
        example_live_event = azure.media.LiveEvent("exampleLiveEvent",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            media_services_account_name=example_service_account.name,
            description="My Event Description",
            input=azure.media.LiveEventInputArgs(
                streaming_protocol="RTMP",
                key_frame_interval_duration="PT6S",
                ip_access_control_allows=[azure.media.LiveEventInputIpAccessControlAllowArgs(
                    name="AllowAll",
                    address="0.0.0.0",
                    subnet_prefix_length=0,
                )],
            ))
        example_live_event_output = azure.media.LiveEventOutput("exampleLiveEventOutput",
            live_event_id=example_live_event.id,
            archive_window_duration="PT5M",
            asset_name=example_asset.name,
            description="Test live output 1",
            manifest_name="testmanifest",
            output_snap_time_in_seconds=0,
            hls_fragments_per_ts_segment=5,
            rewind_window_duration="PT5M")
        ```

        ## Import

        Live Outputs can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:media/liveEventOutput:LiveEventOutput example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Media/mediaServices/account1/liveEvents/event1/liveOutputs/output1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] archive_window_duration: `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] asset_name: The asset that the live output will write to. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] description: The description of the live output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] hls_fragments_per_ts_segment: The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] live_event_id: The id of the live event. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] manifest_name: The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] name: The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] output_snap_time_in_seconds: The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] rewind_window_duration: `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LiveEventOutputArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Azure Media Live Event Output.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_account = azure.storage.Account("exampleAccount",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            account_tier="Standard",
            account_replication_type="GRS")
        example_service_account = azure.media.ServiceAccount("exampleServiceAccount",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            storage_accounts=[azure.media.ServiceAccountStorageAccountArgs(
                id=example_account.id,
                is_primary=True,
            )])
        example_asset = azure.media.Asset("exampleAsset",
            resource_group_name=example_resource_group.name,
            media_services_account_name=example_service_account.name)
        example_live_event = azure.media.LiveEvent("exampleLiveEvent",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            media_services_account_name=example_service_account.name,
            description="My Event Description",
            input=azure.media.LiveEventInputArgs(
                streaming_protocol="RTMP",
                key_frame_interval_duration="PT6S",
                ip_access_control_allows=[azure.media.LiveEventInputIpAccessControlAllowArgs(
                    name="AllowAll",
                    address="0.0.0.0",
                    subnet_prefix_length=0,
                )],
            ))
        example_live_event_output = azure.media.LiveEventOutput("exampleLiveEventOutput",
            live_event_id=example_live_event.id,
            archive_window_duration="PT5M",
            asset_name=example_asset.name,
            description="Test live output 1",
            manifest_name="testmanifest",
            output_snap_time_in_seconds=0,
            hls_fragments_per_ts_segment=5,
            rewind_window_duration="PT5M")
        ```

        ## Import

        Live Outputs can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:media/liveEventOutput:LiveEventOutput example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Media/mediaServices/account1/liveEvents/event1/liveOutputs/output1
        ```

        :param str resource_name: The name of the resource.
        :param LiveEventOutputArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LiveEventOutputArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 archive_window_duration: Optional[pulumi.Input[str]] = None,
                 asset_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hls_fragments_per_ts_segment: Optional[pulumi.Input[int]] = None,
                 live_event_id: Optional[pulumi.Input[str]] = None,
                 manifest_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 output_snap_time_in_seconds: Optional[pulumi.Input[int]] = None,
                 rewind_window_duration: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LiveEventOutputArgs.__new__(LiveEventOutputArgs)

            if archive_window_duration is None and not opts.urn:
                raise TypeError("Missing required property 'archive_window_duration'")
            __props__.__dict__["archive_window_duration"] = archive_window_duration
            if asset_name is None and not opts.urn:
                raise TypeError("Missing required property 'asset_name'")
            __props__.__dict__["asset_name"] = asset_name
            __props__.__dict__["description"] = description
            __props__.__dict__["hls_fragments_per_ts_segment"] = hls_fragments_per_ts_segment
            if live_event_id is None and not opts.urn:
                raise TypeError("Missing required property 'live_event_id'")
            __props__.__dict__["live_event_id"] = live_event_id
            __props__.__dict__["manifest_name"] = manifest_name
            __props__.__dict__["name"] = name
            __props__.__dict__["output_snap_time_in_seconds"] = output_snap_time_in_seconds
            __props__.__dict__["rewind_window_duration"] = rewind_window_duration
        super(LiveEventOutput, __self__).__init__(
            'azure:media/liveEventOutput:LiveEventOutput',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            archive_window_duration: Optional[pulumi.Input[str]] = None,
            asset_name: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            hls_fragments_per_ts_segment: Optional[pulumi.Input[int]] = None,
            live_event_id: Optional[pulumi.Input[str]] = None,
            manifest_name: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            output_snap_time_in_seconds: Optional[pulumi.Input[int]] = None,
            rewind_window_duration: Optional[pulumi.Input[str]] = None) -> 'LiveEventOutput':
        """
        Get an existing LiveEventOutput resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] archive_window_duration: `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] asset_name: The asset that the live output will write to. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] description: The description of the live output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] hls_fragments_per_ts_segment: The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] live_event_id: The id of the live event. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] manifest_name: The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] name: The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        :param pulumi.Input[int] output_snap_time_in_seconds: The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        :param pulumi.Input[str] rewind_window_duration: `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LiveEventOutputState.__new__(_LiveEventOutputState)

        __props__.__dict__["archive_window_duration"] = archive_window_duration
        __props__.__dict__["asset_name"] = asset_name
        __props__.__dict__["description"] = description
        __props__.__dict__["hls_fragments_per_ts_segment"] = hls_fragments_per_ts_segment
        __props__.__dict__["live_event_id"] = live_event_id
        __props__.__dict__["manifest_name"] = manifest_name
        __props__.__dict__["name"] = name
        __props__.__dict__["output_snap_time_in_seconds"] = output_snap_time_in_seconds
        __props__.__dict__["rewind_window_duration"] = rewind_window_duration
        return LiveEventOutput(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="archiveWindowDuration")
    def archive_window_duration(self) -> pulumi.Output[str]:
        """
        `ISO 8601` time between 1 minute to 25 hours to indicate the maximum content length that can be archived in the asset for this live output. This also sets the maximum content length for the rewind window. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of archive window. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "archive_window_duration")

    @property
    @pulumi.getter(name="assetName")
    def asset_name(self) -> pulumi.Output[str]:
        """
        The asset that the live output will write to. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "asset_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the live output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="hlsFragmentsPerTsSegment")
    def hls_fragments_per_ts_segment(self) -> pulumi.Output[Optional[int]]:
        """
        The number of fragments in an HTTP Live Streaming (HLS) TS segment in the output of the live event. This value does not affect the packing ratio for HLS CMAF output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "hls_fragments_per_ts_segment")

    @property
    @pulumi.getter(name="liveEventId")
    def live_event_id(self) -> pulumi.Output[str]:
        """
        The id of the live event. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "live_event_id")

    @property
    @pulumi.getter(name="manifestName")
    def manifest_name(self) -> pulumi.Output[str]:
        """
        The manifest file name. If not provided, the service will generate one automatically. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "manifest_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Live Event Output. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="outputSnapTimeInSeconds")
    def output_snap_time_in_seconds(self) -> pulumi.Output[Optional[int]]:
        """
        The initial timestamp that the live output will start at, any content before this value will not be archived. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "output_snap_time_in_seconds")

    @property
    @pulumi.getter(name="rewindWindowDuration")
    def rewind_window_duration(self) -> pulumi.Output[Optional[str]]:
        """
        `ISO 8601` time between 1 minute to the duration of `archive_window_duration` to control seek-able window length during Live. The service won't use this property once LiveOutput stops. The archived VOD will have full content with original ArchiveWindowLength. For example, use `PT1H30M` to indicate 1 hour and 30 minutes of rewind window length. Service will use implicit default value 30m only if Live Event enables LL. Changing this forces a new Live Output to be created.
        """
        return pulumi.get(self, "rewind_window_duration")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['NetappVolumeAttachmentArgs', 'NetappVolumeAttachment']

@pulumi.input_type
class NetappVolumeAttachmentArgs:
    def __init__(__self__, *,
                 netapp_volume_id: pulumi.Input[str],
                 vmware_cluster_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NetappVolumeAttachment resource.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        pulumi.set(__self__, "netapp_volume_id", netapp_volume_id)
        pulumi.set(__self__, "vmware_cluster_id", vmware_cluster_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="netappVolumeId")
    def netapp_volume_id(self) -> pulumi.Input[str]:
        """
        The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "netapp_volume_id")

    @netapp_volume_id.setter
    def netapp_volume_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "netapp_volume_id", value)

    @property
    @pulumi.getter(name="vmwareClusterId")
    def vmware_cluster_id(self) -> pulumi.Input[str]:
        """
        The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.

        > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        return pulumi.get(self, "vmware_cluster_id")

    @vmware_cluster_id.setter
    def vmware_cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vmware_cluster_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _NetappVolumeAttachmentState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 netapp_volume_id: Optional[pulumi.Input[str]] = None,
                 vmware_cluster_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NetappVolumeAttachment resources.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if netapp_volume_id is not None:
            pulumi.set(__self__, "netapp_volume_id", netapp_volume_id)
        if vmware_cluster_id is not None:
            pulumi.set(__self__, "vmware_cluster_id", vmware_cluster_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="netappVolumeId")
    def netapp_volume_id(self) -> Optional[pulumi.Input[str]]:
        """
        The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "netapp_volume_id")

    @netapp_volume_id.setter
    def netapp_volume_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "netapp_volume_id", value)

    @property
    @pulumi.getter(name="vmwareClusterId")
    def vmware_cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.

        > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        return pulumi.get(self, "vmware_cluster_id")

    @vmware_cluster_id.setter
    def vmware_cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vmware_cluster_id", value)


class NetappVolumeAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 netapp_volume_id: Optional[pulumi.Input[str]] = None,
                 vmware_cluster_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a VMware Private Cloud Netapp File Attachment.

        ## Import

        VMware Private Clouds Netapp File Volume Attachment can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:avs/netappVolumeAttachment:NetappVolumeAttachment example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.AVS/privateClouds/privateCloud1/clusters/Cluster1/dataStores/datastore1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetappVolumeAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a VMware Private Cloud Netapp File Attachment.

        ## Import

        VMware Private Clouds Netapp File Volume Attachment can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:avs/netappVolumeAttachment:NetappVolumeAttachment example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.AVS/privateClouds/privateCloud1/clusters/Cluster1/dataStores/datastore1
        ```

        :param str resource_name: The name of the resource.
        :param NetappVolumeAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetappVolumeAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 netapp_volume_id: Optional[pulumi.Input[str]] = None,
                 vmware_cluster_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetappVolumeAttachmentArgs.__new__(NetappVolumeAttachmentArgs)

            __props__.__dict__["name"] = name
            if netapp_volume_id is None and not opts.urn:
                raise TypeError("Missing required property 'netapp_volume_id'")
            __props__.__dict__["netapp_volume_id"] = netapp_volume_id
            if vmware_cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'vmware_cluster_id'")
            __props__.__dict__["vmware_cluster_id"] = vmware_cluster_id
        super(NetappVolumeAttachment, __self__).__init__(
            'azure:avs/netappVolumeAttachment:NetappVolumeAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            netapp_volume_id: Optional[pulumi.Input[str]] = None,
            vmware_cluster_id: Optional[pulumi.Input[str]] = None) -> 'NetappVolumeAttachment':
        """
        Get an existing NetappVolumeAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetappVolumeAttachmentState.__new__(_NetappVolumeAttachmentState)

        __props__.__dict__["name"] = name
        __props__.__dict__["netapp_volume_id"] = netapp_volume_id
        __props__.__dict__["vmware_cluster_id"] = vmware_cluster_id
        return NetappVolumeAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="netappVolumeId")
    def netapp_volume_id(self) -> pulumi.Output[str]:
        """
        The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "netapp_volume_id")

    @property
    @pulumi.getter(name="vmwareClusterId")
    def vmware_cluster_id(self) -> pulumi.Output[str]:
        """
        The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.

        > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        return pulumi.get(self, "vmware_cluster_id")

